package il.ac.tau.cs.sw1.simplesearch;


import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;

/**
 * A <code>SimpleSearchEngine</code> builds an index o words given a list
 * of predefined URLs. It then will run word searches initiated by the user. 
 */
public class SimpleSearchEngine {
	
	private WordIndex indexer;  // reference to a WordIndex instance

	/**
	 * Create a new SimpleSearchEngine
	 * @param index - An instance of mplementing the {@link WordIndex} interface.
	 */
	public SimpleSearchEngine(WordIndex index) {
		this.indexer = index;
	}
	
	/**
	 * Populate the index and run searches
	 */
	public void run() {
		indexURLs(indexer);
		doSearches(indexer);
	}

	private static void indexURLs(WordIndex indexer) {
		for (String strURL : strURLs) {
			System.out.println("Indexing \"" + strURL + "\" ...");
			indexer.index(HTMLTokenizer.getTokens(strURL), strURL);
		}
	}
	
	private static void doSearches(WordIndex indexer) {
		
		try {
			BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
			String str = null;
			do {
				System.out.print("> ");
				str = in.readLine().trim();
				if (str.equals("(exit)")) {
					break;
				}
				List<String> results = indexer.search(str);
				if (results == null  || results.size() == 0) {
					System.out.println("Unable to find the word you requested");
				} else {
					for (int i = 0; i < results.size(); ++i) {
						System.out.println(i + 1 + ".\t" + results.get(i));
					}
				}
			} while (true);

		} catch (IOException e) { }
		
		System.out.println("Thank you for using SimpleSearch");
	}

	/**
	 * a list of urls we wish to index.
	 * feel free to add/remove urls from this list.
	 */
	static private String[] strURLs = {
		"http://en.wikipedia.org/wiki/Java_(programming_language)",
		"http://en.wikipedia.org/wiki/Java",
		"http://www.gutenberg.org/files/4300/4300-h/4300-h.htm",
		"http://www.java.com/en/",
		"http://www.gutenberg.org/files/11/11-h/11-h.htm",
		"http://www.gutenberg.org/files/12/12-h/12-h.htm",
		"http://www.gutenberg.org/files/27152/27152-h/27152-h.htm"
	};
}
